@@ -7,7 +7,7 @@ use Example::Syntax;
 extends 'Example::Controller';
 
 sub root :At('$path_end/...') Via('../public')  ($self, $c, $user) {
-  return $c->redirect_to_action('/home/user_home') && $c->detach if $user->registered;
+  return $c->redirect_to_action('/home/user_show') && $c->detach if $user->registered;
   $c->action->next($user);
 }
 
@@ -16,12 +16,12 @@ sub root :At('$path_end/...') Via('../public')  ($self, $c, $user) {
     $c->action->next($user);
   }
 
-    sub build :Get('new') Via('prepare_build') ($self, $c, $user) { }
+    # GET /register/new
+    sub build :Get('new') Via('prepare_build') ($self, $c, $user) { return }
 
+    # POST /register
     sub create :Post('') Via('prepare_build') BodyModel ($self, $c, $user, $bm) {
-      return $user->register($bm) ?
-        $c->redirect_to_action('/session/build') :
-          $c->view->set_http_bad_request;
+      return $c->redirect_to_action('/session/build') if $user->register($bm);
     }
 
 __PACKAGE__->meta->make_immutable; 
